@@ -1,5 +1,5 @@
 'Useful functions and classes for PyGame'
-__version__ = '1.5.1'
+__version__ = '1.5.2'
 failed_imports = []
 
 try:
@@ -52,7 +52,7 @@ try:
 except ImportError as e:
 	failed_imports.append(e.name)
 
-print('''\nDo help(pgeng.<Function>) to get the documentation of the function (or possibly class)
-Or do help(pgeng.<Package Content>) to get the documentation of the functions or classes in a file\n''')
+print('''\nRun help(pgeng.<Function>) to get the documentation of the function (or possibly class)
+Or run help(pgeng.<Package Content>) to get the documentation of the functions or classes in a file\n''')
 print(f'Failed to import: {", ".join([failed_import.split(".")[-1] + " from " + ".".join(failed_import.split(".")[:-1]) if "pgeng" in failed_import else failed_import for failed_import in set(failed_imports)])}') if failed_imports else None
 del failed_imports
\ No newline at end of file
